#ifndef INCLUDE_MSGHANDLER_H
#define INCLUDE_MSGHANDLER_H
/* ----------------------------------------------------------------------------
 * msghandler.h
 * prototypes and definitions for msghandler.c.
 *
 * Copyright 2002 Matthias Grimm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 * ----------------------------------------------------------------------------*/

#include <gtk/gtk.h>
#include <pbb.h>

#include "init.h"

#define POLLTIME				10	/* in miliseconds */

/* prototypes */
gint timeout_callback(gpointer data);
int get_server_config(struct basedata *base);
int set_server_config(struct basedata *base);
int store_config_tag (struct basedata *base, long tag, long data);
int garbage_collection (struct basedata *base);

#ifdef HAVE_OLDLIBPBB     /* support for older libpbb.a */
struct tagitem* find_tagitem (struct tagitem *taglist, long tag);
int taglist_count (struct tagitem *taglist);
#endif

#endif    /* INCLUDE_MSGHANDLER_H */
